==> haskell-xcffib-0.5.1-43-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcffib
version: 0.5.1
id: xcffib-0.5.1-JS1N0PaVvrvKWS58qBRq4H
key: xcffib-0.5.1-JS1N0PaVvrvKWS58qBRq4H
license: OtherLicense
maintainer: Tycho Andersen <tycho@tycho.ws>
homepage: http://github.com/tych0/xcffib
synopsis: A cffi-based python binding for X
description:
    A cffi-based python binding for X, comparable to xpyb
category: X11
author: Tycho Andersen
exposed: True
indefinite: False
exposed-modules:
    Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
abi: 9cd04bc561f7e69ad54a58549a05c7b5
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/xcffib-0.5.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/xcffib-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/xcffib-0.5.1
hs-libraries: HSxcffib-0.5.1-JS1N0PaVvrvKWS58qBRq4H
depends:
    base-4.10.0.0 xcb-types-0.8.0-EpOJ2VRKLyF9G8YzHLov0Z
    language-python-0.5.4-C0nHOJ1TAMtBM9UDEQKYiX filepath-1.4.1.2
    filemanip-0.3.6.3-HRazNawHUwUFMqg3mdq5t4
    split-0.2.3.2-89BHvn20PlL73pGr1SBIHj containers-0.5.10.2
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm bytestring-0.10.8.2
    either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             xcb-types-0.8.0-EpOJ2VRKLyF9G8YzHLov0Z=97abc110e2f7d600d3bc9f7a686daf77
             language-python-0.5.4-C0nHOJ1TAMtBM9UDEQKYiX=a5f71ff2272ca65d729d94070b57cd9e
             filepath-1.4.1.2=30ad74f2069d36b2d0af3972630d4ac4
             filemanip-0.3.6.3-HRazNawHUwUFMqg3mdq5t4=b91a5463c2064866a369c9188c3b10bf
             split-0.2.3.2-89BHvn20PlL73pGr1SBIHj=c51f43c3e91d41531ae5282d108271a0
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=5531911f09693672654e6de645ce55e7
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=08dd59974100c688bef2cfbf42e32e82
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj=297872866a18209138b91c7d03fed159
haddock-interfaces: /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html: /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcffib-0.5.1-44-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcffib
version: 0.5.1
id: xcffib-0.5.1-Fk55MzjGTsuCg8uvAJuOnw
key: xcffib-0.5.1-Fk55MzjGTsuCg8uvAJuOnw
license: OtherLicense
maintainer: Tycho Andersen <tycho@tycho.ws>
homepage: http://github.com/tych0/xcffib
synopsis: A cffi-based python binding for X
description:
    A cffi-based python binding for X, comparable to xpyb
category: X11
author: Tycho Andersen
exposed: True
indefinite: False
exposed-modules:
    Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
abi: a5e97ebb6527ced1a3115f43b9436403
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/xcffib-0.5.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/xcffib-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/xcffib-0.5.1
hs-libraries: HSxcffib-0.5.1-Fk55MzjGTsuCg8uvAJuOnw
depends:
    base-4.10.0.0 xcb-types-0.8.0-EpOJ2VRKLyF9G8YzHLov0Z
    language-python-0.5.4-C0nHOJ1TAMtBM9UDEQKYiX filepath-1.4.1.2
    filemanip-0.3.6.3-HRazNawHUwUFMqg3mdq5t4
    split-0.2.3.2-89BHvn20PlL73pGr1SBIHj containers-0.5.10.2
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm bytestring-0.10.8.2
    either-4.5-LYT0d6MLKlX83NrOtw2Pp2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             xcb-types-0.8.0-EpOJ2VRKLyF9G8YzHLov0Z=97abc110e2f7d600d3bc9f7a686daf77
             language-python-0.5.4-C0nHOJ1TAMtBM9UDEQKYiX=a5f71ff2272ca65d729d94070b57cd9e
             filepath-1.4.1.2=30ad74f2069d36b2d0af3972630d4ac4
             filemanip-0.3.6.3-HRazNawHUwUFMqg3mdq5t4=b91a5463c2064866a369c9188c3b10bf
             split-0.2.3.2-89BHvn20PlL73pGr1SBIHj=c51f43c3e91d41531ae5282d108271a0
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=5531911f09693672654e6de645ce55e7
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=08dd59974100c688bef2cfbf42e32e82
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             either-4.5-LYT0d6MLKlX83NrOtw2Pp2=62288d5afd316da1ac78a82ed181db6f
haddock-interfaces: /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html: /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
